/*
 * Copyright (c) 2001-2007 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

package com.jgoodies.looks.plastic;

import java.awt.event.MouseEvent;

import javax.swing.AbstractButton;
import javax.swing.plaf.basic.BasicButtonListener;

/**
 * Unlike its superclass this class sets the armed state when the mouse is over
 * the button, where the 1.4 superclass sets the armed state only if the button
 * is pressed.
 * 
 * @author Karsten Lentzsch
 * @version $Revision: 1.2 $
 */

@SuppressWarnings("all")
final class ActiveBasicButtonListener extends BasicButtonListener {

  private boolean mouseOver;

  ActiveBasicButtonListener(AbstractButton b) {
    super(b);
    mouseOver = false;
  }

  public void mouseEntered(MouseEvent e) {
    super.mouseEntered(e);
    AbstractButton button = (AbstractButton) e.getSource();
    button.getModel().setArmed(mouseOver = true);
  }

  public void mouseExited(MouseEvent e) {
    super.mouseExited(e);
    AbstractButton button = (AbstractButton) e.getSource();
    button.getModel().setArmed(mouseOver = false);
  }

  public void mouseReleased(MouseEvent e) {
    super.mouseReleased(e);
    AbstractButton button = (AbstractButton) e.getSource();
    button.getModel().setArmed(mouseOver);
  }

}
